@@ -27,6 +27,11 @@
 #include <vtkm/VectorAnalysis.h>
 #include <vtkm/exec/FunctorBase.h>
 
+#if (defined(VTKM_GCC) || defined(VTKM_CLANG))
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wconversion"
+#endif // gcc || clang
+
 namespace vtkm
 {
 namespace exec
@@ -67,8 +72,8 @@ VTKM_EXEC typename WorldCoordVector::ComponentType ReverseInterpolateTriangle(
   //
   // In this diagram, the distance between p0 and the point marked x divided by
   // the length of the edge it is on is equal, by proportionality, to the u
-  // parametric coordiante. (The v coordinate follows the other edge
-  // accordingly.) Thus, if we can find the interesection at x (or more
+  // parametric coordinate. (The v coordinate follows the other edge
+  // accordingly.) Thus, if we can find the intersection at x (or more
   // specifically the distance between p0 and x), then we can find that
   // parametric coordinate.
   //
@@ -81,7 +86,7 @@ VTKM_EXEC typename WorldCoordVector::ComponentType ReverseInterpolateTriangle(
   //
   // First, we define an implicit plane as:
   //
-  // dot((p - wcoords), planeNormal) = 0
+  // Dot((p - wcoords), planeNormal) = 0
   //
   // where planeNormal is the normal to the plane (easily computed from the
   // triangle), and p is any point in the plane. Next, we define the parametric
@@ -94,13 +99,13 @@ VTKM_EXEC typename WorldCoordVector::ComponentType ReverseInterpolateTriangle(
   // compute it, we are done. We can skip the part about finding the actual
   // coordinates of the intersection.
   //
-  // Solving for the interesection is as simple as substituting the line's
+  // Solving for the intersection is as simple as substituting the line's
   // definition of p(d) into p for the plane equation. With some basic algebra
   // you get:
   //
-  // d = dot((wcoords - p0), planeNormal)/dot((p1-p0), planeNormal)
+  // d = Dot((wcoords - p0), planeNormal)/Dot((p1-p0), planeNormal)
   //
-  // From here, the u coordiante is simply d. The v coordinate follows
+  // From here, the u coordinate is simply d. The v coordinate follows
   // similarly.
   //
 
@@ -117,7 +122,7 @@ VTKM_EXEC typename WorldCoordVector::ComponentType ReverseInterpolateTriangle(
     Vector3 p2 = pointWCoords[2 - dimension];
     Vector3 planeNormal = vtkm::Cross(triangleNormal, p2 - p0);
 
-    T d = vtkm::dot(wcoords - p0, planeNormal) / vtkm::dot(p1 - p0, planeNormal);
+    T d = vtkm::Dot(wcoords - p0, planeNormal) / vtkm::Dot(p1 - p0, planeNormal);
 
     pcoords[dimension] = d;
   }
@@ -267,10 +272,9 @@ VTKM_EXEC typename FieldVecType::ComponentType CellInterpolate(
   ParametricCoordType angle = vtkm::ATan2(pcoords[1] - 0.5f, pcoords[0] - 0.5f);
   if (angle < 0)
   {
-    angle += static_cast<ParametricCoordType>(2 * vtkm::Pi());
+    angle += 2 * vtkm::Pi<ParametricCoordType>();
   }
-  const ParametricCoordType deltaAngle =
-    static_cast<ParametricCoordType>(2 * vtkm::Pi() / numPoints);
+  const ParametricCoordType deltaAngle = 2 * vtkm::Pi<ParametricCoordType>() / numPoints;
   vtkm::IdComponent firstPointIndex =
     static_cast<vtkm::IdComponent>(vtkm::Floor(angle / deltaAngle));
   vtkm::IdComponent secondPointIndex = firstPointIndex + 1;
@@ -441,4 +445,8 @@ VTKM_EXEC typename FieldVecType::ComponentType CellInterpolate(
 }
 } // namespace vtkm::exec
 
+#if (defined(VTKM_GCC) || defined(VTKM_CLANG))
+#pragma GCC diagnostic pop
+#endif // gcc || clang
+
 #endif //vtk_m_exec_Interpolate_h
