@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkGradientFilter extends vtkDataSetAlgorithm
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -135,6 +135,38 @@ public class vtkGradientFilter extends vtkDataSetAlgorithm
   public void ComputeQCriterionOff()
     { ComputeQCriterionOff_31(); }
 
+  private native void SetContributingCellOption_32(int id0);
+  public void SetContributingCellOption(int id0)
+    { SetContributingCellOption_32(id0); }
+
+  private native int GetContributingCellOptionMinValue_33();
+  public int GetContributingCellOptionMinValue()
+    { return GetContributingCellOptionMinValue_33(); }
+
+  private native int GetContributingCellOptionMaxValue_34();
+  public int GetContributingCellOptionMaxValue()
+    { return GetContributingCellOptionMaxValue_34(); }
+
+  private native int GetContributingCellOption_35();
+  public int GetContributingCellOption()
+    { return GetContributingCellOption_35(); }
+
+  private native void SetReplacementValueOption_36(int id0);
+  public void SetReplacementValueOption(int id0)
+    { SetReplacementValueOption_36(id0); }
+
+  private native int GetReplacementValueOptionMinValue_37();
+  public int GetReplacementValueOptionMinValue()
+    { return GetReplacementValueOptionMinValue_37(); }
+
+  private native int GetReplacementValueOptionMaxValue_38();
+  public int GetReplacementValueOptionMaxValue()
+    { return GetReplacementValueOptionMaxValue_38(); }
+
+  private native int GetReplacementValueOption_39();
+  public int GetReplacementValueOption()
+    { return GetReplacementValueOption_39(); }
+
   public vtkGradientFilter() { super(); }
 
   public vtkGradientFilter(long id) { super(id); }
