@@ -15,13 +15,13 @@ public class vtkInteractorStyle3D extends vtkInteractorStyle
   public int IsA(String id0)
     { return IsA_1(id0); }
 
-  private native void SetDollyMotionFactor_2(double id0);
-  public void SetDollyMotionFactor(double id0)
-    { SetDollyMotionFactor_2(id0); }
+  private native void SetDollyPhysicalSpeed_2(double id0);
+  public void SetDollyPhysicalSpeed(double id0)
+    { SetDollyPhysicalSpeed_2(id0); }
 
-  private native double GetDollyMotionFactor_3();
-  public double GetDollyMotionFactor()
-    { return GetDollyMotionFactor_3(); }
+  private native double GetDollyPhysicalSpeed_3();
+  public double GetDollyPhysicalSpeed()
+    { return GetDollyPhysicalSpeed_3(); }
 
   private native void SetScale_4(vtkCamera id0,double id1);
   public void SetScale(vtkCamera id0,double id1)
